checklist: Create a checklist

View source: R/checklist.R

checklistR Documentation

Create a checklist

Description

This function returns all taxa observed for a given set of filters. Users can, for example, return all taxa from a particular Phylum or from a certain geographic region.

Usage

checklist(scientificname = NULL, taxonid = NULL, datasetid = NULL,
  nodeid = NULL, instituteid = NULL, areaid = NULL, startdate = NULL, enddate = NULL,
  startdepth = NULL, enddepth = NULL, geometry = NULL, redlist = NULL,
  hab = NULL, wrims = NULL, dropped = NULL, flags = NULL, exclude = NULL,
  verbose = FALSE)

Arguments

scientificname

the scientific name.

taxonid

the taxon identifier (WoRMS AphiaID).

datasetid

the dataset identifier.

nodeid

the OBIS node identifier.

instituteid

the OBIS institute identifier.

areaid

the OBIS area identifier.

startdate

the earliest date on which occurrence took place.

enddate

the latest date on which the occurrence took place.

startdepth

the minimum depth below the sea surface.

enddepth

the maximum depth below the sea surface.

geometry

a WKT geometry string.

redlist

include only IUCN Red List species.

hab

include only IOC-UNESCO HAB species.

wrims

include only WRiMS species.

dropped

only include dropped records (TRUE), exclude dropped records (NULL) or include dropped records (include).

flags

quality flags which need to be set.

exclude

quality flags to be excluded from the results.

verbose

logical. Optional parameter to enable verbose logging (default = FALSE).

Value

A checklist (tibble), with the records that met the filter.

Note

When using a geometry, the function will fail if the geometry is too complex. One alternative is to use a bounding box or a simplified version of the geometry.

Examples

taxa <- checklist(scientificname = "Tellinidae")
taxa <- checklist(geometry = "POLYGON ((2.3 51.8, 2.3 51.6, 2.6 51.6, 2.6 51.8, 2.3 51.8))")
taxa <- checklist(areaid = 10181)

robis documentation built on July 25, 2026, 1:07 a.m.