dataset: Create a list of datasets.

View source: R/dataset.R

datasetR Documentation

Create a list of datasets.

Description

Create a list of datasets.

Usage

dataset(scientificname = NULL, taxonid = NULL, datasetid = NULL,
  nodeid = NULL, instituteid = NULL, areaid = NULL, startdate = NULL,
  enddate = NULL, startdepth = NULL, enddepth = NULL, geometry = NULL,
  redlist = NULL, hab = NULL, wrims = NULL, hasextensions = NULL,
  exclude = NULL, keyword = NULL, verbose = FALSE)

Arguments

scientificname

the scientific name.

taxonid

the taxon identifier (WoRMS AphiaID).

datasetid

the dataset identifier.

nodeid

the OBIS node identifier.

instituteid

the OBIS institute identifier.

areaid

the OBIS area identifier.

startdate

the earliest date on which occurrence took place.

enddate

the latest date on which the occurrence took place.

startdepth

the minimum depth below the sea surface.

enddepth

the maximum depth below the sea surface.

geometry

a WKT geometry string.

redlist

include only IUCN Red List species.

hab

include only IOC-UNESCO HAB species.

wrims

include only WRiMS species.

hasextensions

which extensions need to be present (e.g. MeasurementOrFact, DNADerivedData).

exclude

quality flags to be excluded from the results.

keyword

Keyword(s) to search for in dataset metadata. When keyword is used, no other filter parameters may be specified.

The search uses Elasticsearch simple_query_string syntax. The following symbolic operators are supported:

  • +: Equivalent to AND, requiring all terms. Any whitespace is also an implicit AND. For example, coral+reef is equivalent to coral reef.

  • Quotes ("..."): Used for exact phrase matching. For example, "coral reef" is stricter than the unquoted version.

  • |: Equivalent to OR. Returns records where any listed term is present.

  • -: Equivalent to NOT. Excludes records containing the specified term.

  • *: Wildcard matching is supported only at the end of a word. For example, star* matches "starfish" and sea* matches "seastar". However, *star* returns no results, and leading wildcards like *star may appear to work in some cases but should not be relied upon.

  • Grouping with parentheses: (coral | kelp) -fish returns results that include coral OR kelp, but NOT fish. Removing the parentheses would change the meaning — it would return results that include coral, or kelp only when fish is also present (i.e., coral OR (kelp -fish)).

verbose

logical. Optional parameter to enable verbose logging (default = FALSE).

Value

A tibble of matching datasets.

Examples

## Not run: 
dataset(scientificname = "Tellinidae")
dataset(areaid = 10181)
dataset(keyword = '(coral | kelp) -fish')

## End(Not run)

robis documentation built on July 25, 2026, 1:07 a.m.