| occurrence | R Documentation |
Download occurrence records from OBIS. A set of filters can be used to delimit which data will be downloaded. Note that scientificname can be a species name or any other taxon name (e.g. a family name).
occurrence(scientificname = NULL, taxonid = NULL, datasetid = NULL,
nodeid = NULL, instituteid = NULL, areaid = NULL, startdate = NULL, enddate = NULL,
startdepth = NULL, enddepth = NULL, geometry = NULL,
measurementtype = NULL, measurementtypeid = NULL, measurementvalue = NULL,
measurementvalueid = NULL, measurementunit = NULL, measurementunitid = NULL,
redlist = NULL, hab = NULL, wrims = NULL, extensions = NULL, hasextensions = NULL,
mof = NULL, dna = NULL, absence = NULL, event = NULL, dropped = NULL,
flags = NULL, exclude = NULL, fields = NULL, qcfields = NULL, q=NULL, verbose = FALSE)
scientificname |
the scientific name. |
taxonid |
the taxon identifier (WoRMS AphiaID). |
datasetid |
the dataset identifier. |
nodeid |
the OBIS node identifier. |
instituteid |
the OBIS institute identifier. |
areaid |
the OBIS area identifier. |
startdate |
the earliest date on which occurrence took place. |
enddate |
the latest date on which the occurrence took place. |
startdepth |
the minimum depth below the sea surface. |
enddepth |
the maximum depth below the sea surface. |
geometry |
a WKT geometry string. |
measurementtype |
the measurement type to be included in the measurements data. |
measurementtypeid |
the measurement type ID to be included in the measurements data. |
measurementvalue |
the measurement value to be included in the measurements data. |
measurementvalueid |
the measurement value ID to be included in the measurements data. |
measurementunit |
the measurement unit to be included in the measurements data. |
measurementunitid |
the measurement unit ID to be included in the measurements data. |
redlist |
include only IUCN Red List species. |
hab |
include only IOC-UNESCO HAB species. |
wrims |
include only WRiMS species. |
extensions |
which extensions to include (e.g. MeasurementOrFact, DNADerivedData, default = |
hasextensions |
which extensions need to be present (e.g. MeasurementOrFact, DNADerivedData, default = |
mof |
include measurements data (default = |
dna |
include DNA data (default = |
absence |
only include absence records ( |
event |
only include pure event records ( |
dropped |
only include dropped records ( |
flags |
quality flags which need to be set. |
exclude |
quality flags to be excluded from the results. |
fields |
fields to be included in the results. |
qcfields |
include lists of missing and invalid fields (default = |
q |
text search query. |
verbose |
logical. Optional parameter to enable verbose logging (default = |
The occurrence records in a tibble format. The number of columns will vary according to the number of information associated with the records.
For more information about the type of data available with OBIS occurrences, see the OBIS manual.
When using a geometry, the function will fail if the geometry is too complex. One alternative is to use a bounding box or a simplified version of the geometry.
records <- occurrence(scientificname = "Abra sibogai")
records <- occurrence(taxonid = 141438, startdate = as.Date("2007-10-10"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.