Learn R Programming

robis (version 2.12.0)

unnest_extension: Extract extension records from occurrence data with nested extension column.

Description

Extract extension records from occurrence data with nested extension column.

Usage

unnest_extension(df, extension, fields = "id")

Value

The extension records.

Arguments

df

the occurrence dataframe.

extension

the extension type (e.g. MeasurementOrFact, DNADerivedData).

fields

columns from the occurrence dataframe to include.