Create a list of datasets.
dataset(scientificname = NULL, taxonid = NULL, datasetid = NULL,
nodeid = NULL, instituteid = NULL, areaid = NULL, startdate = NULL,
enddate = NULL, startdepth = NULL, enddepth = NULL, geometry = NULL,
redlist = NULL, hab = NULL, wrims = NULL, hasextensions = NULL,
exclude = NULL, keyword = NULL, verbose = FALSE)A tibble of matching datasets.
the scientific name.
the taxon identifier (WoRMS AphiaID).
the dataset identifier.
the OBIS node identifier.
the OBIS institute identifier.
the OBIS area identifier.
the earliest date on which occurrence took place.
the latest date on which the occurrence took place.
the minimum depth below the sea surface.
the maximum depth below the sea surface.
a WKT geometry string.
include only IUCN Red List species.
include only IOC-UNESCO HAB species.
include only WRiMS species.
which extensions need to be present (e.g. MeasurementOrFact, DNADerivedData).
quality flags to be excluded from the results.
Keyword(s) to search for in dataset metadata. When keyword is used, no other filter parameters may be specified.
The search uses Elasticsearch simple_query_string syntax.
The following symbolic operators are supported:
+: Equivalent to AND, requiring all terms. Any whitespace is also an implicit AND.
For example, coral+reef is equivalent to coral reef.
Quotes ("..."): Used for exact phrase matching. For example, "coral reef" is stricter than the unquoted version.
|: Equivalent to OR. Returns records where any listed term is present.
-: Equivalent to NOT. Excludes records containing the specified term.
*: Wildcard matching is supported only at the end of a word.
For example, star* matches "starfish" and sea* matches "seastar".
However, *star* returns no results, and leading wildcards like *star may appear to work
in some cases but should not be relied upon.
Grouping with parentheses: (coral | kelp) -fish returns results that include coral OR kelp, but NOT fish.
Removing the parentheses would change the meaning — it would return results that include coral,
or kelp only when fish is also present (i.e., coral OR (kelp -fish)).
logical. Optional parameter to enable verbose logging (default = FALSE).
if (FALSE) {
dataset(scientificname = "Tellinidae")
dataset(areaid = 10181)
dataset(keyword = '(coral | kelp) -fish')
}
Run the code above in your browser using DataLab